/*
 * Copyright (C) 2000-2006 by ETH Zurich
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ETH ZURICH AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL ETH ZURICH
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.btnode.ethz.ch
 *
 */

/*
 * \example btsense-cmd/btsense-cmd.c
 *
 * \date 2006/09/22
 *
 * \author bosterm
 * 
 * Simple example application for the btsense board.
 */

#include "program_version.h"
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <hardware/btn-hardware.h>
#include <terminal/btn-terminal.h>
#include <terminal/btn-cmds.h>
#include <btsense/btsense-cmds.h>
#include <btsense/btsense.h>
#include <dev/usartavr.h>
#include <led/btn-led.h>
#include <sys/timer.h>

#define UART_SPEED 57600

/**
 * Initialises the first UART and the terminal.
 */
static void term_init(void) 
{
    FILE *uart_terminal;
    u_long baud = 57600;
            
    /* initialize UART 1 */
    NutRegisterDevice(&APP_UART, 0, 0);
    uart_terminal = fopen(APP_UART.dev_name, "r+");
    _ioctl(_fileno(uart_terminal), UART_SETSPEED, &baud);
    btn_terminal_init(uart_terminal, "[bt-cmd@btnode]$");
    freopen(APP_UART.dev_name, "w", stdout);    
}

/**
 * Initializes the BTnode.
 */
static void btnode_init(void) 
{    
    /* initialize the btnode hardware */
    btn_hardware_init();
    btn_led_init(0);
    term_init(); 
}

/* Simple beep command */
void beep_cmd(char* arg)
{
	btsense_sound( 440 );
	NutSleep(1000);
	btsense_sound( 0 );
}

/**
 * Registers all supported commands.
 */
static void register_cmds(void)
{
    btn_cmds_register_cmds();
    btsense_cmds_register_cmds();
   	btn_terminal_register_cmd("beep", beep_cmd);
}

int main(void)
{
	btnode_init();
	btsense_init( BTSENSE_REVISION_1_1A );
    
    DEBUGB("\n# ----------------------------------------");
    DEBUGB("\n# BTsense (c) 2006 ETH Zurich\n");
    DEBUGT("# program version: %s\n", PROGRAM_VERSION);
    DEBUGB("# ----------------------------------------\n");
    NutSleep(200);
 
    // register cmds
	register_cmds();
    
    // start terminal
    btn_terminal_run(BTN_TERMINAL_NOFORK, 1024);
    
    return 1;
}
