/*
 * Copyright (C) 2000-2004 by ETH Zurich
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ETH ZURICH AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL ETH ZURICH
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.btnode.ethz.ch
 *
 */


/**
 * \file hardware/btn-hardware.h
 * \author Martin Hinz <btnode@hinz.ch>
 * 
 * @brief Functions to init and control all hardware dependend calls.
 * 
 * \attention Use always btn_hardware_init() function in your program code to include
 * the init0 section to turn on xsram at the very beginning. 
 *
 * 26.05.2004 Martin Hinz <btnode@hinz.ch>
 */
#ifndef BTN_HARDWARE_H_INCLUDED
#define BTN_HARDWARE_H_INCLUDED

#include <sys/types.h>
#include <arch/btn-hardware.h>
#include <hardware/btn-latch.h>

/**
 * this init function has to be called by every application at the beginning
 * of the main procedure. with the call of this function the init0 section 
 * with the xsram settings will be set
 */
void btn_hardware_init(void);


/**
 * This function turns on the power of the bt module and the bt radio,
 * does a reset of the module and sleeps for a short period of time
 * to let the bt module boot
 */
void btn_hardware_bt_on(void);

/**
 * This function turns off the power of the bt module and the bt radio
 * and hold the reset pin
 *
 * only available on BTnode3
 */
void btn_hardware_bt_power_off(void);

/**
 * This function turns on the power of the bt module and the bt radio,
 * release the reset pin and let the bt module boot
 *
 * only available on BTnode3
 */
void btn_hardware_bt_power_on(void);

/**
 * turns the bt radio on and off
 * @param on 1=on/ 0=off
 * 
 * only available on Ericsson modules in BTnode2
 */
void btn_hardware_bt_radio_power(u_char on);

/**
 * controlls the reset pin on the bt module
 * @param reset 1=reset/ 0=no reset
 */
void btn_hardware_bt_reset(u_char reset);

/**
 * turns power latch of bt module on and off
 * @param on 1=on/ 0=off
 */
void btn_hardware_bt_power(u_char on);

/**
 * turns power latch of cc1000 radio on and off
 * @param on 1=on/ 0=off
 */
void btn_hardware_cc1000_power(u_char on);

/**
* turns power latch of external hardware on and off
 * @param on 1=on/ 0=off
 */
void btn_hardware_io_power(u_char on);

#endif
